@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::CCR;
-$Search::Elasticsearch::Client::6_0::Direct::CCR::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::CCR::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::CCR::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
@@ -20,7 +19,7 @@ Search::Elasticsearch::Client::6_0::Direct::CCR - Plugin providing cross-cluster
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head2 DESCRIPTION
 
