@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::6_0::Direct::Nodes;
-$Search::Elasticsearch::Client::6_0::Direct::Nodes::VERSION = '6.00';
+$Search::Elasticsearch::Client::6_0::Direct::Nodes::VERSION = '6.81';
 use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::6_0::Direct::Nodes - A client for running node-le
 
 =head1 VERSION
 
-version 6.00
+version 6.81
 
 =head1 DESCRIPTION
 
@@ -155,6 +155,24 @@ Query string parameters:
 See the L<hot_threads docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html>
 for more information.
 
+=head2 C<reload_secure_settings()>
+
+    $response = $e->nodes->reload_secure_settings(
+        node_id => $node_id | \@node_ids    # optional
+    );
+
+The C<reload_secure_settings()> API will reload the reloadable settings stored in the keystore
+on each node.
+
+Query string parameters:
+    C<error_trace>,
+    C<filter_path>,
+    C<human>,
+    C<timeout>
+
+See the L<reload-secure-settings docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/secure-settings.html>
+for more information.
+
 =head2 C<usage()>
 
     $response = $e->nodes->usage(
@@ -174,11 +192,11 @@ for more information.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
