@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Role::Scroll;
-$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.81';
+use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Devel::GlobalDestruction;
@@ -64,7 +63,7 @@ Search::Elasticsearch::Client::6_0::Role::Scroll - Provides common functionality
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 AUTHOR
 
